@@ -118,13 +118,21 @@ class AttributeCache:
         self.task = RepeatableTask(self.api.event_loop, self._async_value, EVICT_TIME)
         self._value: Any = None
         self._mutex = asyncio.Lock()
+        self.unsupported: bool = False
 
     @property
     def value(self):
         return self._value
 
     async def _async_value(self):
-        self._value = await self.api._send_command(self.attribute.get_command)
+        if self.unsupported:
+            return None
+        try:
+            self._value = await self.api._send_command(self.attribute.get_command)
+        except UnknownMethodError as err:
+            # Limit the amount of times we call unsupported methods
+            self.unsupported = True
+            raise err
         return self._value
 
     async def async_value(self):
@@ -161,9 +169,6 @@ class AttributeCache:
         await self._async_value()
 
 
-device_cache: dict[str, dict[CacheableAttribute, AttributeCache]] = {}
-
-
 class RoborockClient:
     def __init__(self, endpoint: str, device_info: DeviceData, queue_timeout: int = 4) -> None:
         self.event_loop = get_running_loop_or_create_one()
@@ -176,20 +181,22 @@ class RoborockClient:
         self.keep_alive = KEEPALIVE
         self._diagnostic_data: dict[str, dict[str, Any]] = {}
         self._logger = RoborockLoggerAdapter(device_info.device.name, _LOGGER)
-        cache = device_cache.get(device_info.device.duid)
-        if not cache:
-            cache = {
-                cacheable_attribute: AttributeCache(attr, self) for cacheable_attribute, attr in get_cache_map().items()
-            }
-            device_cache[device_info.device.duid] = cache
-        self.cache: dict[CacheableAttribute, AttributeCache] = cache
+        self.cache: dict[CacheableAttribute, AttributeCache] = {
+            cacheable_attribute: AttributeCache(attr, self) for cacheable_attribute, attr in get_cache_map().items()
+        }
         self._listeners: list[Callable[[str, CacheableAttribute, RoborockBase], None]] = []
-        self.is_available: bool = False
+        self.is_available: bool = True
         self.queue_timeout = queue_timeout
+        self._status_type: type[Status] = ModelStatus.get(self.device_info.model, S7MaxVStatus)
 
     def __del__(self) -> None:
         self.release()
 
+    @property
+    def status_type(self) -> type[Status]:
+        """Gets the status type for this device"""
+        return self._status_type
+
     def release(self):
         self.sync_disconnect()
         [item.stop() for item in self.cache.values()]
@@ -253,17 +260,14 @@ class RoborockClient:
                                 data_protocol = RoborockDataProtocol(int(data_point_number))
                                 self._logger.debug(f"Got device update for {data_protocol.name}: {data_point}")
                                 if data_protocol in ROBOROCK_DATA_STATUS_PROTOCOL:
-                                    _cls: type[Status] = ModelStatus.get(
-                                        self.device_info.model, S7MaxVStatus
-                                    )  # Default to S7 MAXV if we don't have the data
                                     if self.cache[CacheableAttribute.status].value is None:
                                         self._logger.debug(
                                             f"Got status update({data_protocol.name}) before get_status was called."
                                         )
-                                        self.cache[CacheableAttribute.status]._value = {}
+                                        return
                                     value = self.cache[CacheableAttribute.status].value
                                     value[data_protocol.name] = data_point
-                                    status = _cls.from_dict(value)
+                                    status = self._status_type.from_dict(value)
                                     for listener in self._listeners:
                                         listener(self.device_info.device.duid, CacheableAttribute.status, status)
                                 elif data_protocol in ROBOROCK_DATA_CONSUMABLE_PROTOCOL:
@@ -272,7 +276,7 @@ class RoborockClient:
                                             f"Got consumable update({data_protocol.name})"
                                             + "before get_consumable was called."
                                         )
-                                        self.cache[CacheableAttribute.consumable]._value = {}
+                                        return
                                     value = self.cache[CacheableAttribute.consumable].value
                                     value[data_protocol.name] = data_point
                                     consumable = Consumable.from_dict(value)
@@ -289,7 +293,10 @@ class RoborockClient:
                     payload = data.payload[0:24]
                     [endpoint, _, request_id, _] = struct.unpack("<8s8sH6s", payload)
                     if endpoint.decode().startswith(self._endpoint):
-                        decrypted = Utils.decrypt_cbc(data.payload[24:], self._nonce)
+                        try:
+                            decrypted = Utils.decrypt_cbc(data.payload[24:], self._nonce)
+                        except ValueError as err:
+                            raise RoborockException("Failed to decode %s for %s", data.payload, data.protocol) from err
                         decompressed = Utils.decompress(decrypted)
                         queue = self._waiting_queue.get(request_id)
                         if queue:
@@ -406,10 +413,7 @@ class RoborockClient:
         return response
 
     async def get_status(self) -> Status | None:
-        _cls: type[Status] = ModelStatus.get(
-            self.device_info.model, S7MaxVStatus
-        )  # Default to S7 MAXV if we don't have the data
-        return _cls.from_dict(await self.cache[CacheableAttribute.status].async_value())
+        return self._status_type.from_dict(await self.cache[CacheableAttribute.status].async_value())
 
     async def get_dnd_timer(self) -> DnDTimer | None:
         return DnDTimer.from_dict(await self.cache[CacheableAttribute.dnd_timer].async_value())
@@ -436,7 +440,16 @@ class RoborockClient:
         return None
 
     async def get_clean_record(self, record_id: int) -> CleanRecord | None:
-        return await self.send_command(RoborockCommand.GET_CLEAN_RECORD, [record_id], return_type=CleanRecord)
+        record: dict | list = await self.send_command(RoborockCommand.GET_CLEAN_RECORD, [record_id])
+        if isinstance(record, dict):
+            return CleanRecord.from_dict(record)
+        elif isinstance(record, list):
+            # There are still a few unknown variables in this.
+            begin, end, duration, area = unpack_list(record, 4)
+            return CleanRecord(begin=begin, end=end, duration=duration, area=area)
+        else:
+            _LOGGER.warning("Clean record was of a new type, please submit an issue request: %s", record)
+            return None
 
     async def get_consumable(self) -> Consumable | None:
         return Consumable.from_dict(await self.cache[CacheableAttribute.consumable].async_value())
